#!/usr/bin/env python
# coding: utf-8

# In[1]:


from graphtransliterator import GraphTransliterator
easyreading_yaml = """
tokens:
  k: [consonant]
  kh: [consonant]
  g: [consonant]
  gh: [consonant]
  ~N: [consonant]
  "\N{LATIN SMALL LETTER N WITH DOT ABOVE}": [consonant]
  ch: [consonant]
  chh: [consonant]
  Ch: [consonant]
  j: [consonant]
  jh: [consonant]
  ~n: [consonant]
  T: [consonant]
  Th: [consonant]
  D: [consonant]
  Dh: [consonant]
  N: [consonant]
  t: [consonant]
  th: [consonant]
  d: [consonant]
  dh: [consonant]
  n: [consonant]
  ^n: [consonant]
  p: [consonant]
  ph: [consonant]
  b: [consonant]
  bh: [consonant]
  m: [consonant]
  y: [consonant]
  r: [consonant]
  R: [consonant]
  l: [consonant]
  ld: [consonant]
  L: [consonant]
  zh: [consonant]
  v: [consonant]
  sh: [consonant]
  Sh: [consonant]
  s: [consonant]
  h: [consonant]
  x: [consonant]
  kSh: [consonant]
  GY: [consonant]
  j~n: [consonant]
  dny: [consonant]
  q: [consonant]
  K: [consonant]
  G: [consonant]
  J: [consonant]
  z: [consonant]
  .D: [consonant]
  .Dh: [consonant]
  f: [consonant]
  Y: [consonant]
  a: [vowel]
  aa: [vowel]
  A: [vowel]
  i: [vowel]
  ii: [vowel]
  I: [vowel]
  ee: [vowel]
  u: [vowel]
  uu: [vowel]
  U: [vowel]
  RRi: [vowel]
  R^i: [vowel]
  LLi: [vowel]
  L^i: [vowel]
  RRI: [vowel]
  LLI: [vowel]
  a.c: [vowel]
  ^e: [vowel]
  e: [vowel]
  ai: [vowel]
  A.c: [vowel]
  ^o: [vowel]
  o: [vowel]
  au: [vowel]
  ' ': [wb,whitespace]
  "\t": [wb,whitespace]
  ',': [wb]
  .h: [wb]
  H: [wb]
  OM: [wb]
  AUM: [wb]
  '|': [wb]
  '||': [wb]
  '0': [wb]
  '1': [wb]
  '2': [wb]
  '3': [wb]
  '4': [wb]
  '5': [wb]
  '6': [wb]
  '7': [wb]
  '8': [wb]
  '9': [wb]
  Rs.: [wb]
  ~Rs.: [wb]
  .a: [wb]
  a.e: [vowel_sign]
  .N: [vowel_sign]
  .n: [vowel_sign]
  M: [vowel_sign]
  .m: [vowel_sign]
rules:
  "\t": "\t"
  ' ': ' '
  ',': ','
  .D: "\N{DEVANAGARI LETTER DDDHA}"
  .Dh: "\N{DEVANAGARI LETTER RHA}"
  .N: "\N{DEVANAGARI SIGN CANDRABINDU}"
  .a: "\N{DEVANAGARI SIGN AVAGRAHA}"
  .h: "\N{DEVANAGARI SIGN VIRAMA}\N{ZERO WIDTH NON-JOINER}"
  .m: "\N{DEVANAGARI SIGN ANUSVARA}"
  .n: "\N{DEVANAGARI SIGN ANUSVARA}"
  '0': "\N{DEVANAGARI DIGIT ZERO}"
  '1': "\N{DEVANAGARI DIGIT ONE}"
  '2': "\N{DEVANAGARI DIGIT TWO}"
  '3': "\N{DEVANAGARI DIGIT THREE}"
  '4': "\N{DEVANAGARI DIGIT FOUR}"
  '5': "\N{DEVANAGARI DIGIT FIVE}"
  '6': "\N{DEVANAGARI DIGIT SIX}"
  '7': "\N{DEVANAGARI DIGIT SEVEN}"
  '8': "\N{DEVANAGARI DIGIT EIGHT}"
  '9': "\N{DEVANAGARI DIGIT NINE}"
  <consonant> A: "\N{DEVANAGARI VOWEL SIGN AA}"
  <consonant> A.c: "\N{DEVANAGARI VOWEL SIGN CANDRA O}"
  <consonant> I: "\N{DEVANAGARI VOWEL SIGN II}"
  <consonant> LLI: "\N{DEVANAGARI VOWEL SIGN VOCALIC LL}"
  <consonant> LLi: "\N{DEVANAGARI VOWEL SIGN VOCALIC L}"
  <consonant> L^i: "\N{DEVANAGARI VOWEL SIGN VOCALIC L}"
  <consonant> RRI: "\N{DEVANAGARI VOWEL SIGN VOCALIC RR}"
  <consonant> RRi: "\N{DEVANAGARI VOWEL SIGN VOCALIC R}"
  <consonant> R^i: "\N{DEVANAGARI VOWEL SIGN VOCALIC R}"
  <consonant> U: "\N{DEVANAGARI VOWEL SIGN UU}"
  <consonant> ^e: "\N{DEVANAGARI VOWEL SIGN SHORT E}"
  <consonant> ^o: "\N{DEVANAGARI VOWEL SIGN SHORT O}"
  <consonant> a: ''
  <consonant> a.c: "\N{DEVANAGARI VOWEL SIGN CANDRA E}"
  <consonant> aa: "\N{DEVANAGARI VOWEL SIGN AA}"
  <consonant> ai: "\N{DEVANAGARI VOWEL SIGN AI}"
  <consonant> au: "\N{DEVANAGARI VOWEL SIGN AU}"
  <consonant> e: "\N{DEVANAGARI VOWEL SIGN E}"
  <consonant> ee: "\N{DEVANAGARI VOWEL SIGN II}"
  <consonant> i: "\N{DEVANAGARI VOWEL SIGN I}"
  <consonant> ii: "\N{DEVANAGARI VOWEL SIGN II}"
  <consonant> o: "\N{DEVANAGARI VOWEL SIGN O}"
  <consonant> u: "\N{DEVANAGARI VOWEL SIGN U}"
  <consonant> uu: "\N{DEVANAGARI VOWEL SIGN UU}"
  A: "\N{DEVANAGARI LETTER AA}"
  A.c: "\N{DEVANAGARI LETTER CANDRA O}"
  AUM: "\N{DEVANAGARI OM}"
  Ch: "\N{DEVANAGARI LETTER CHA}"
  D: "\N{DEVANAGARI LETTER DDA}"
  Dh: "\N{DEVANAGARI LETTER DDHA}"
  G: "\N{DEVANAGARI LETTER GHHA}"
  GY: "\N{DEVANAGARI LETTER JA}\N{DEVANAGARI SIGN VIRAMA}\N{DEVANAGARI LETTER NYA}"
  H: "\N{DEVANAGARI SIGN VISARGA}"
  I: "\N{DEVANAGARI LETTER II}"
  J: "\N{DEVANAGARI LETTER ZA}"
  K: "\N{DEVANAGARI LETTER KHHA}"
  L: "\N{DEVANAGARI LETTER LLA}"
  LLI: "\N{DEVANAGARI LETTER VOCALIC LL}"
  LLi: "\N{DEVANAGARI LETTER VOCALIC L}"
  L^i: "\N{DEVANAGARI LETTER VOCALIC L}"
  M: "\N{DEVANAGARI SIGN ANUSVARA}"
  N: "\N{DEVANAGARI LETTER NNA}"
  OM: "\N{DEVANAGARI OM}"
  R: "\N{DEVANAGARI LETTER RRA}"
  RRI: "\N{DEVANAGARI LETTER VOCALIC RR}"
  RRi: "\N{DEVANAGARI LETTER VOCALIC R}"
  R^i: "\N{DEVANAGARI LETTER VOCALIC R}"
  Rs.: "\N{INDIAN RUPEE SIGN}"
  Sh: "\N{DEVANAGARI LETTER SSA}"
  T: "\N{DEVANAGARI LETTER TTA}"
  Th: "\N{DEVANAGARI LETTER TTHA}"
  U: "\N{DEVANAGARI LETTER UU}"
  Y: "\N{DEVANAGARI LETTER YYA}"
  ^e: "\N{DEVANAGARI LETTER SHORT E}"
  ^n: "\N{DEVANAGARI LETTER NNNA}"
  ^o: "\N{DEVANAGARI LETTER SHORT O}"
  a: "\N{DEVANAGARI LETTER A}"
  a.c: "\N{DEVANAGARI LETTER CANDRA E}"
  a.e: "\N{DEVANAGARI LETTER CANDRA A}"
  aa: "\N{DEVANAGARI LETTER AA}"
  ai: "\N{DEVANAGARI LETTER AI}"
  au: "\N{DEVANAGARI LETTER AU}"
  b: "\N{DEVANAGARI LETTER BA}"
  bh: "\N{DEVANAGARI LETTER BHA}"
  ch: "\N{DEVANAGARI LETTER CA}"
  chh: "\N{DEVANAGARI LETTER CHA}"
  d: "\N{DEVANAGARI LETTER DA}"
  dh: "\N{DEVANAGARI LETTER DHA}"
  dny: "\N{DEVANAGARI LETTER JA}\N{DEVANAGARI SIGN VIRAMA}\N{DEVANAGARI LETTER NYA}"
  e: "\N{DEVANAGARI LETTER E}"
  ee: "\N{DEVANAGARI LETTER II}"
  f: "\N{DEVANAGARI LETTER FA}"
  g: "\N{DEVANAGARI LETTER GA}"
  gh: "\N{DEVANAGARI LETTER GHA}"
  h: "\N{DEVANAGARI LETTER HA}"
  i: "\N{DEVANAGARI LETTER I}"
  ii: "\N{DEVANAGARI LETTER II}"
  j: "\N{DEVANAGARI LETTER JA}"
  jh: "\N{DEVANAGARI LETTER JHA}"
  j~n: "\N{DEVANAGARI LETTER JA}\N{DEVANAGARI SIGN VIRAMA}\N{DEVANAGARI LETTER NYA}"
  k: "\N{DEVANAGARI LETTER KA}"
  kSh: "\N{DEVANAGARI LETTER KA}\N{DEVANAGARI SIGN VIRAMA}\N{DEVANAGARI LETTER SSA}"
  kh: "\N{DEVANAGARI LETTER KHA}"
  l: "\N{DEVANAGARI LETTER LA}"
  ld: "\N{DEVANAGARI LETTER LLA}"
  m: "\N{DEVANAGARI LETTER MA}"
  n: "\N{DEVANAGARI LETTER NA}"
  o: "\N{DEVANAGARI LETTER O}"
  p: "\N{DEVANAGARI LETTER PA}"
  ph: "\N{DEVANAGARI LETTER PHA}"
  q: "\N{DEVANAGARI LETTER QA}"
  r: "\N{DEVANAGARI LETTER RA}"
  s: "\N{DEVANAGARI LETTER SA}"
  sh: "\N{DEVANAGARI LETTER SHA}"
  t: "\N{DEVANAGARI LETTER TA}"
  th: "\N{DEVANAGARI LETTER THA}"
  u: "\N{DEVANAGARI LETTER U}"
  uu: "\N{DEVANAGARI LETTER UU}"
  v: "\N{DEVANAGARI LETTER VA}"
  x: "\N{DEVANAGARI LETTER KA}\N{DEVANAGARI SIGN VIRAMA}\N{DEVANAGARI LETTER SSA}"
  y: "\N{DEVANAGARI LETTER YA}"
  z: "\N{DEVANAGARI LETTER ZA}"
  zh: "\N{DEVANAGARI LETTER LLLA}"
  '|': "\N{DEVANAGARI DANDA}"
  '||': "\N{DEVANAGARI DOUBLE DANDA}"
  ~N: "\N{DEVANAGARI LETTER NGA}"
  ~Rs.: "\N{INDIAN RUPEE SIGN}"
  ~n: "\N{DEVANAGARI LETTER NYA}"
  "\N{LATIN SMALL LETTER N WITH DOT ABOVE}": "\N{DEVANAGARI LETTER NGA}"
onmatch_rules:
- <consonant> + <consonant>: "\N{DEVANAGARI SIGN VIRAMA}"
whitespace:
  consolidate: false
  default: ' '
  token_class: whitespace
metadata:
  title: ITRANS to Unicode
  version: 0.1.0
"""
gt = GraphTransliterator.from_yaml(easyreading_yaml)


# In[2]:


gt.transliterate("aaj mausam ba.Daa beiimaan hai, aaj mausam")


# In[3]:


gt.last_matched_rules


# In[4]:


gt.last_matched_rule_tokens


# In[5]:


gt.graph

